@@ -1,14 +1,7 @@
-from a3m.server.tasks.backends import GearmanTaskBackend
 from a3m.server.tasks.backends import get_task_backend
 from a3m.server.tasks.backends import PoolTaskBackend
 from a3m.server.tasks.backends import TaskBackend
 from a3m.server.tasks.task import Task
 
 
-__all__ = (
-    "GearmanTaskBackend",
-    "PoolTaskBackend",
-    "Task",
-    "TaskBackend",
-    "get_task_backend",
-)
+__all__ = ("PoolTaskBackend", "Task", "TaskBackend", "get_task_backend")
